@@ -23,6 +23,9 @@ from .exec import (
     select_one,
     query,
     query_one,
+    select_page,
+    query_page,
+    load,
     do_execute,
     do_save_sql,
     do_save_sql_select_key,
@@ -31,17 +34,14 @@ from .exec import (
     do_select_one,
     do_query,
     do_query_one,
-    select_page,
-    query_page,
     do_select_page,
     do_query_page,
-    load,
     do_load,
     insert_from_csv,
     insert_from_df,
     insert_from_json,
-    truncate,
-    drop
+    truncate_table,
+    drop_table
 )
 
 from .sql_exec import sql
