@@ -1,4 +1,4 @@
-from executor.constant import LIMIT_1
+LIMIT_1 = 1
 
 CACHE_SIZE = 256
 
