@@ -83,8 +83,8 @@ def try_mapping(function, sql, *args, **kwargs):
 
 
 def get_table_select_sql(table_name: str, where: str, limit: Union[int, Tuple[int], List[int]], *columns):
-    columns = ','.join([col if '(' in col else '{}'.format(col) for col in columns]) if columns else Dialect.get_table_columns(table_name)
-
+    columns = Dialect.get_dialect_str(columns) if columns else Dialect.get_table_columns(table_name)
+    table_name = Dialect.get_dialect_str(table_name)
     if limit:
         if isinstance(limit, int):
             return 'SELECT {} FROM {} {} LIMIT ?'.format(columns, table_name, where)
